@@ -566,6 +566,8 @@ camel_vee_store_new (void)
  *
  * FIXME Document me!
  *
+ * Returns: (transfer none):
+ *
  * Since: 3.6
  **/
 CamelVeeDataCache *
@@ -581,6 +583,8 @@ camel_vee_store_get_vee_data_cache (CamelVeeStore *vstore)
  *
  * FIXME Document me!
  *
+ * Returns: (transfer none):
+ *
  * Since: 3.6
  **/
 CamelVeeFolder *
@@ -1021,13 +1025,15 @@ camel_vee_store_rebuild_unmatched_folder (CamelVeeStore *vstore,
 		service = CAMEL_SERVICE (vstore);
 		session = camel_service_ref_session (service);
 
-		camel_session_submit_job (
-			session, _("Updating Unmatched search folder"), (CamelSessionCallback)
-			vee_store_rebuild_unmatched_folder,
-			g_object_ref (vstore),
-			g_object_unref);
+		if (session) {
+			camel_session_submit_job (
+				session, _("Updating Unmatched search folder"), (CamelSessionCallback)
+				vee_store_rebuild_unmatched_folder,
+				g_object_ref (vstore),
+				g_object_unref);
 
-		g_object_unref (session);
+			g_object_unref (session);
+		}
 	} else {
 		vee_store_rebuild_unmatched_folder (NULL, cancellable, vstore, error);
 	}
